__version__ = "2.4.0"

import logging

from . import errors, vlrs, file
from .copc import CopcReader, Bounds
from .errors import LaspyException
from .laswriter import LasWriter
from .lasreader import LasReader
from .lib import LazBackend, DecompressionSelection, convert
from .lib import create_las as create
from .lib import mmap_las as mmap
from .lib import open_las as open
from .lib import read_las as read
from .point import PointFormat, ExtraBytesParams, DimensionKind, DimensionInfo
from .point.record import PackedPointRecord, ScaleAwarePointRecord
from .point.dims import supported_point_formats, supported_versions
from .point.format import lost_dimensions
from .header import LasHeader
from .lasdata import LasData
from .vlrs import VLR

logging.getLogger(__name__).addHandler(logging.NullHandler())
